Crate token_dict
token_
dict
1.3.0
All Items
Crate Items
Re-exports
Modules
Structs
Traits
Functions
Crate
token_
dict
Re-exports

pub use dict::
TokenDict
;
pub use token::
Token
;
Modules

dict
module for token dictionary
token
module for Token type
Structs

UTF8
Char
Iter
iterator for live converting utf8 to chars, returning errors for all bytes that aren’t part of a valid character. useful for lazily detokenizing into a string
Traits

Val
trait for unifying primitives and their references
Functions

dict_
to_
file_
lines
write a TokenDict to a file as lines. Assumes tokens are valid UTF8 and single line
file_
lines_
to_
dict
read tokens separated by line from a file into a TokenDict. Assumes tokens are valid UTF8 and single line